import React, { useState } from "react"
import Taro from "@tarojs/taro"
import { View, Input, Picker } from "@tarojs/components"
import withLayout from '@/layouts'
import CustomNav from "@/components/CustomNav"
import MyButton from "@/components/MyButton"
import { useModel } from "@/store"
import { addBank } from '@/services/bank'
import './style.less'

const bankList = [
  {
    key: 1,
    value: '中国建设银行'
  },
  {
    key: 2,
    value: '中国农业银行'
  },
  {
    key: 3,
    value: '中国银行'
  },
  // {
  //   key: 4,
  //   value: '中国工商银行'
  // },
  // {
  //   key: 5,
  //   value: '中国招商银行'
  // },
  // {
  //   key: 6,
  //   value: '中国交通银行'
  // },
  // {
  //   key: 7,
  //   value: '中国邮政银行'
  // },
]
const bankContentList = ['中国建设银行', '中国农业银行', '中国银行']

export default withLayout((props) => {
  const { person } = useModel('person')
  const [name, setName] = useState()
  const [bankCode, setBankCode] = useState()
  const [bankAddress, setBankAddress] = useState(bankContentList[0])
  const [phone, setPhone] = useState()
  const [index, setIndex] = useState(0)
  const [loading, setLoading] = useState(false)


  const onChange = e => {
    console.log(bankList[e.detail.value])
    setBankAddress(bankContentList[e.detail.value])
    setIndex(e.detail.value)
  }
  const rulePhone = (val) => {
    if (!/^1[0-9]{10}$/.test(val)) {
      Taro.showToast({
        title: '请输入正确的11位手机号',
        icon: 'none',
        duration: 2000
      })
      return false
    } else return true
  }
  const ruleCard = (val) => {
    if (!/[0-9]{19}$/.test(val)) {
      Taro.showToast({
        title: '请输入正确的19位银行卡号',
        icon: 'none',
        duration: 2000
      })
      return false
    } else return true
  }
  const onClick = () => {
    if (name) {
      if (ruleCard(bankCode) && rulePhone(phone)) {
        setLoading(true)
        addBank({ cardNo: bankCode, personId: person.personId, ownerBank: bankAddress, owerName: name, phone: phone }).then(res => {
          Taro.showToast({
            title: '添加成功',
            icon: 'none',
            duration: 2000
          })
          setTimeout(() => {
            Taro.navigateBack({ delta: 1 })
          }, 1000)
        }).catch(err => {
          Taro.showToast({
            title: err.message,
            icon: 'none',
            duration: 1000
          })
          setLoading(false)
        })
      }
    } else {
      Taro.showToast({
        title: '请输入持卡人姓名',
        icon: 'none',
      })
    }
  }
  return (
    <View className='page-index'>
      <View className='index-navbar'>
        <CustomNav title='我的银行卡' />
      </View>
      <View className='index-container addBankCard'>
        <View className='title'>请绑定持卡人本人的银行卡</View>
        <View className='addCardCell'>
          <View className='cellLeft'>
            <View className='label'>持卡人姓名</View>：</View>
          <Input type='text' value={name} onInput={(e) => setName(e.detail.value)} placeholder='请输入真实姓名' />
        </View>
        <View className='addCardCell'>
          <View className='cellLeft'>
            <View className='label'>卡号</View>：
          </View>
          <Input type='number' maxlength='19' value={bankCode} onInput={(e) => setBankCode(e.detail.value)} placeholder='请输入有效卡号' />
        </View>
        <View className='addCardCell'>
          <View className='cellLeft'>
            <View className='label'>开户行</View>：
          </View>
          <Picker mode='selector' style={{ width: '100%' }} range={bankContentList} onChange={onChange}>
            {bankContentList[index]}
          </Picker>
        </View>
        <View className='addCardCell'>
          <View className='cellLeft'>
            <View className='label'>预留手机号</View>：
          </View>
          <Input type='number' maxlength='11' value={phone} onInput={(e) => setPhone(e.detail.value)} placeholder='请输入银行卡预留手机号' />
        </View>
        <View className='bottomBtn'>
          <MyButton loading={loading} value='提现' onClick={onClick} />
        </View>
      </View>
    </View>
  )
})
