import Taro, { useDidShow } from "@tarojs/taro"
import { useState, useEffect } from "react"
import { View, Image, Input, Picker } from "@tarojs/components"
import CustomNav from "@/components/CustomNav"
import WalletCard from "@/components/walletCard"
import ListTitle from "@/components/ListTitle"
import MyButton from "@/components/MyButton"
import withLayout from '@/layouts'
import { getBankList } from '@/services/bank'
import goto from '@/assets/user/goto.png'
import addImg from '@/assets/bank/addBank.png'
import './style.less'


export default withLayout((props) => {
  const { router } = props
  let { balance } = router.params
  const [money, setMoney] = useState()
  const [bankList, setBankList] = useState([])
  const [bankContentList, setBankContentList] = useState([])

  const [index, setIndex] = useState(0)
  const onChange = e => {
    console.log(bankList[e.detail.value])
    setIndex(e.detail.value)
  }

  const onClick = () => {
    if (money) {
      if ((money - 0) > balance) {
        Taro.showToast({
          title: '您的余额不足',
          icon: 'none',
        })
      } else {
        Taro.showToast({
          title: '提交成功，1到3个工作日将到您的付款账户',
          icon: 'none',
        })
        // 刷新页面
      }
    }
    else {
      Taro.showToast({
        title: '请输入本次提现金额',
        icon: 'none',
      })
    }

  }
  const handleChanage = (e) => {
    setMoney(e.detail.value)
  }
  const addCard = () => {
    Taro.navigateTo({ url: '/pages/addBankCard/index' });
  }
  const getList = () => {
    getBankList().then(res => {
      if (res.records.length != 0) {
        setBankList(res.records)
        setBankContentList(res.records.map(item => {
          return item.ownerBank + '(' + item.cardNo.substr(15, 4) + ')'
        }))
      }
    })
  }
  useDidShow(() => {
    getList()
  })
  useEffect(() => {
    getList()
  }, [])
  return (
    <View className='page-index'>
      <View className='index-navbar'>
        <CustomNav title='我的钱包' />
      </View>
      <View className='index-container withdrawal'>
        <WalletCard tixian value={balance} />
        <ListTitle value='选择银行卡' />
        {
          bankList.length == 0 ?
            <View className='addBank' onClick={addCard}>
              <Image src={addImg} className='addIcon' />
              添加银行卡
            </View>
            : <Picker mode='selector' placeholder='请选择提现银行卡' range={bankContentList} onChange={onChange}>
              <View className='bankPicker'>
                <View className='body'>
                  {bankContentList[index]}
                </View>
                <Image className='cell-action-picker' src={goto} />
              </View>
            </Picker>
        }
        <ListTitle value='选择银行卡' />
        <View className='bankInput'>
          <View className='header'>￥</View>
          <Input className='body' type='number' placeholder='请输入提取金额' value={money} onInput={handleChanage} />
        </View>
        <View className='bottomBtn'>
          <MyButton value='提现' onClick={onClick} />
        </View>
      </View>
    </View>
  )
})
